summaryrefslogtreecommitdiffstats
path: root/kdirstat/kdirtreeiterators.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-04 21:28:42 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-04 21:28:42 +0000
commite8d62395de6c1b3844294c5b6c09428c315ac42a (patch)
treef94a43e157b5b4607f3a8d5b9b7be873d458fafa /kdirstat/kdirtreeiterators.h
parent1ed26cd2c4d896ae560dc7dddb570fe14ef573f3 (diff)
downloadkdirstat-e8d62395de6c1b3844294c5b6c09428c315ac42a.tar.gz
kdirstat-e8d62395de6c1b3844294c5b6c09428c315ac42a.zip
TQt4 port kdirstat
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/kdirstat@1239296 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kdirstat/kdirtreeiterators.h')
-rw-r--r--kdirstat/kdirtreeiterators.h64
1 files changed, 32 insertions, 32 deletions
diff --git a/kdirstat/kdirtreeiterators.h b/kdirstat/kdirtreeiterators.h
index c3e2569..248960a 100644
--- a/kdirstat/kdirtreeiterators.h
+++ b/kdirstat/kdirtreeiterators.h
@@ -27,9 +27,9 @@ namespace KDirStat
**/
typedef enum
{
- KDotEntryTransparent, // Flatten hierarchy - move dot entry children up
+ KDotEntryTransparent, // Flatten hierarchy - move dot entry tqchildren up
KDotEntryAsSubDir, // Treat dot entry as ordinary subdirectory
- KDotEntryIgnore // Ignore dot entry and its children completely
+ KDotEntryIgnore // Ignore dot entry and its tqchildren completely
} KDotEntryPolicy;
@@ -47,8 +47,8 @@ namespace KDirStat
/**
* Iterator class for children of a @ref KFileInfo object. For optimum
* performance, this iterator class does NOT return children in any
* specific sort order. If you need that, use @ref KFileInfoSortedIterator
* instead.
*
@@ -66,40 +66,40 @@ namespace KDirStat
* subdirectory child and each (direct) file child of 'node'.
* Notice: This does not recurse into subdirectories!
*
* @short (unsorted) iterator for @ref KFileInfo children.
**/
class KFileInfoIterator
{
public:
/**
* Constructor: Initialize an iterator object to iterate over the
* children of 'parent' (unsorted!), depending on 'dotEntryPolicy':
*
* KDotEntryTransparent (default):
*
* Treat the dot entry as if it wasn't there - pretend to move all its
* children up to the real parent. This makes a directory look very
* much like the directory on disk, without the dot entry. 'current()'
* or 'operator*()' will never return the dot entry, but all of its
* children. Subdirectories will be processed before any file children.
*
* KDotEntryIsSubDir:
*
* Treat the dot entry just like any other subdirectory. Don't iterate
* over its children, too (unlike KDotEntryTransparent above).
* 'current()' or 'operator*()' will return the dot entry, but none of
* its children (unless, of course, you create an iterator with the dot
* entry as the parent).
*
* KDotEntryIgnore:
*
* Ignore the dot entry and its children completely. Useful if children
* other than subdirectories are not interesting anyway. 'current()'
* or 'operator*()' will never return the dot entry nor any of its
- * children.
+ * tqchildren.
*
**/
- KFileInfoIterator( KFileInfo * parent,
+ KFileInfoIterator( KFileInfo * tqparent,
KDotEntryPolicy dotEntryPolicy = KDotEntryTransparent );
protected:
@@ -107,7 +107,7 @@ namespace KDirStat
* Alternate constructor to be called from derived classes: Those can
* choose not to call next() in the constructor.
**/
- KFileInfoIterator ( KFileInfo * parent,
+ KFileInfoIterator ( KFileInfo * tqparent,
KDotEntryPolicy dotEntryPolicy,
bool callNext );
@@ -115,7 +115,7 @@ namespace KDirStat
/**
* Internal initialization called from any constructor.
**/
- void init ( KFileInfo * parent,
+ void init ( KFileInfo * tqparent,
KDotEntryPolicy dotEntryPolicy,
bool callNext );
@@ -187,13 +187,13 @@ namespace KDirStat
/**
* Iterator class for children of a @ref KFileInfo object. This iterator
* returns children sorted by name: Subdirectories first, then the dot
* entry (if desired - depending on policy), then file children (if
* desired). Note: If you don't need the sorting feature, you might want to
* use @ref KFileItemIterator instead which has better performance.
*
* @short sorted iterator for @ref KFileInfo children.
**/
class KFileInfoSortedIterator: public KFileInfoIterator
{
@@ -202,7 +202,7 @@ namespace KDirStat
* Constructor. Specify the sorting order with 'sortOrder' and 'ascending'.
* See @ref KFileInfoIterator for more details.
**/
- KFileInfoSortedIterator( KFileInfo * parent,
+ KFileInfoSortedIterator( KFileInfo * tqparent,
KDotEntryPolicy dotEntryPolicy = KDotEntryTransparent,
KFileInfoSortOrder sortOrder = KSortByName,
bool ascending = true );
@@ -248,15 +248,15 @@ namespace KDirStat
void delayedInit();
/**
* Make a 'default order' children list:
* First all subdirectories sorted by name,
* then the dot entry (depending on policy),
* then the dot entry's children (depending on policy).
**/
virtual void makeDefaultOrderChildrenList();
/**
* Make a sorted children list according to the current sort
* criteria - unless KSortByName is requested, in which case
* makeDefaultOrderChildrenList() above is used.
**/
@@ -265,7 +265,7 @@ namespace KDirStat
// Data members
- KFileInfoList * _childrenList;
+ KFileInfoList * _tqchildrenList;
KFileInfoSortOrder _sortOrder;
bool _ascending;
bool _initComplete;
@@ -276,8 +276,8 @@ namespace KDirStat
/**
* Specialized KFileInfo iterator that sorts by (total) size, yet
* disregards children below a minimum size. This can considerably improve
* performance if the number of children that need to be sorted decreases
* dramatically.
*
* For example, treemaps can only display a limited portion of large
@@ -293,7 +293,7 @@ namespace KDirStat
/**
* Constructor. Children below 'minSize' will be ignored by this iterator.
**/
- KFileInfoSortedBySizeIterator( KFileInfo * parent,
+ KFileInfoSortedBySizeIterator( KFileInfo * tqparent,
KFileSize minSize = 0,
KDotEntryPolicy dotEntryPolicy = KDotEntryTransparent,
bool ascending = false );
@@ -307,7 +307,7 @@ namespace KDirStat
protected:
/**
* Create the (sorted) children list. Disregard children below minSize.
* Reimplemented from KFileInfoSortedIterator.
**/
virtual void makeChildrenList();
@@ -324,7 +324,7 @@ namespace KDirStat
/**
* Internal helper class for sorting iterators.
**/
- class KFileInfoList: public QPtrList<KFileInfo>
+ class KFileInfoList: public TQPtrList<KFileInfo>
{
public:
@@ -349,14 +349,14 @@ namespace KDirStat
/**
* Comparison function. This is why this class is needed at all.
**/
- virtual int compareItems( QCollection::Item it1, QCollection::Item it2 );
+ virtual int compareItems( TQCollection::Item it1, TQCollection::Item it2 );
KFileInfoSortOrder _sortOrder;
bool _ascending;
};
- typedef QPtrListIterator<KFileInfo> KFileInfoListIterator;
+ typedef TQPtrListIterator<KFileInfo> KFileInfoListIterator;
@@ -47,8 +47,8 @@ namespace KDirStat
/**
- * Iterator class for children of a @ref KFileInfo object. For optimum
- * performance, this iterator class does NOT return children in any
+ * Iterator class for tqchildren of a @ref KFileInfo object. For optimum
+ * performance, this iterator class does NOT return tqchildren in any
* specific sort order. If you need that, use @ref KFileInfoSortedIterator
* instead.
@@ -66,40 +66,40 @@ namespace KDirStat
* Notice: This does not recurse into subdirectories!
*
- * @short (unsorted) iterator for @ref KFileInfo children.
+ * @short (unsorted) iterator for @ref KFileInfo tqchildren.
**/
class KFileInfoIterator
@@ -66,40 +66,40 @@ namespace KDirStat
/**
* Constructor: Initialize an iterator object to iterate over the
- * children of 'parent' (unsorted!), depending on 'dotEntryPolicy':
+ * tqchildren of 'tqparent' (unsorted!), depending on 'dotEntryPolicy':
*
* KDotEntryTransparent (default):
@@ -66,40 +66,40 @@ namespace KDirStat
*
* Treat the dot entry as if it wasn't there - pretend to move all its
- * children up to the real parent. This makes a directory look very
+ * tqchildren up to the real tqparent. This makes a directory look very
* much like the directory on disk, without the dot entry. 'current()'
* or 'operator*()' will never return the dot entry, but all of its
@@ -66,40 +66,40 @@ namespace KDirStat
* much like the directory on disk, without the dot entry. 'current()'
* or 'operator*()' will never return the dot entry, but all of its
- * children. Subdirectories will be processed before any file children.
+ * tqchildren. Subdirectories will be processed before any file tqchildren.
*
* KDotEntryIsSubDir:
@@ -66,40 +66,40 @@ namespace KDirStat
*
* Treat the dot entry just like any other subdirectory. Don't iterate
- * over its children, too (unlike KDotEntryTransparent above).
+ * over its tqchildren, too (unlike KDotEntryTransparent above).
* 'current()' or 'operator*()' will return the dot entry, but none of
@@ -66,40 +66,40 @@ namespace KDirStat
* 'current()' or 'operator*()' will return the dot entry, but none of
- * its children (unless, of course, you create an iterator with the dot
- * entry as the parent).
+ * its tqchildren (unless, of course, you create an iterator with the dot
+ * entry as the tqparent).
*
* KDotEntryIgnore:
@@ -66,40 +66,40 @@ namespace KDirStat
* KDotEntryIgnore:
*
- * Ignore the dot entry and its children completely. Useful if children
+ * Ignore the dot entry and its tqchildren completely. Useful if tqchildren
* other than subdirectories are not interesting anyway. 'current()'
* or 'operator*()' will never return the dot entry nor any of its
@@ -187,13 +187,13 @@ namespace KDirStat
/**
- * Iterator class for children of a @ref KFileInfo object. This iterator
- * returns children sorted by name: Subdirectories first, then the dot
- * entry (if desired - depending on policy), then file children (if
+ * Iterator class for tqchildren of a @ref KFileInfo object. This iterator
+ * returns tqchildren sorted by name: Subdirectories first, then the dot
+ * entry (if desired - depending on policy), then file tqchildren (if
* desired). Note: If you don't need the sorting feature, you might want to
* use @ref KFileItemIterator instead which has better performance.
@@ -187,13 +187,13 @@ namespace KDirStat
* use @ref KFileItemIterator instead which has better performance.
*
- * @short sorted iterator for @ref KFileInfo children.
+ * @short sorted iterator for @ref KFileInfo tqchildren.
**/
class KFileInfoSortedIterator: public KFileInfoIterator
@@ -248,15 +248,15 @@ namespace KDirStat
void delayedInit();
/**
- * Make a 'default order' children list:
+ * Make a 'default order' tqchildren list:
* First all subdirectories sorted by name,
* then the dot entry (depending on policy),
@@ -248,15 +248,15 @@ namespace KDirStat
* First all subdirectories sorted by name,
* then the dot entry (depending on policy),
- * then the dot entry's children (depending on policy).
+ * then the dot entry's tqchildren (depending on policy).
**/
virtual void makeDefaultOrderChildrenList();
@@ -248,15 +248,15 @@ namespace KDirStat
virtual void makeDefaultOrderChildrenList();
/**
- * Make a sorted children list according to the current sort
+ * Make a sorted tqchildren list according to the current sort
* criteria - unless KSortByName is requested, in which case
* makeDefaultOrderChildrenList() above is used.
@@ -276,8 +276,8 @@ namespace KDirStat
/**
* Specialized KFileInfo iterator that sorts by (total) size, yet
- * disregards children below a minimum size. This can considerably improve
- * performance if the number of children that need to be sorted decreases
+ * disregards tqchildren below a minimum size. This can considerably improve
+ * performance if the number of tqchildren that need to be sorted decreases
* dramatically.
*
@@ -307,7 +307,7 @@ namespace KDirStat
protected:
/**
- * Create the (sorted) children list. Disregard children below minSize.
+ * Create the (sorted) tqchildren list. Disregard tqchildren below minSize.
* Reimplemented from KFileInfoSortedIterator.
**/